# syntheticusers

**Description**: Synthetic Users provides AI-powered, human-like participants for user and market research, streamlining data collection and insight generation. With multi-agent architecture, it simulates realistic, scalable interactions, enabling efficient research through synthetic interviews and surveys.

**Features**:
- **In-depth Interviews**: Interactive, AI-driven interviews with customizable follow-up options.
- **Global Surveys**: Fast, quantitative data collection at scale.
- **Customizable Synthetic Users**: Integrate proprietary data for tailored research.
- **Multi-agent Framework**: Mimics real human interactions for accurate insights.

**Use Cases**:
- **Product Testing**: Identify needs and refine concepts.
- **Market Analysis**: Expand reach and enhance user satisfaction.
  
For more information, visit [Synthetic Users](https://www.syntheticusers.com).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import syntheticusers
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import syntheticusers
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import syntheticusers
from syntheticusers.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:8000/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = syntheticusers.Configuration(
    host = "http://localhost:8000/api/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = syntheticusers.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with syntheticusers.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = syntheticusers.AnnotationsApi(api_client)
    app_utils_annotation_create1 = syntheticusers.AppUtilsAnnotationCreate1() # AppUtilsAnnotationCreate1 | 

    try:
        # Create Annotation
        api_response = api_instance.create_annotation(app_utils_annotation_create1)
        print("The response of AnnotationsApi->create_annotation:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AnnotationsApi->create_annotation: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8000/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnnotationsApi* | [**create_annotation**](docs/AnnotationsApi.md#create_annotation) | **POST** /annotations | Create Annotation
*AnnotationsApi* | [**delete_annotation**](docs/AnnotationsApi.md#delete_annotation) | **DELETE** /annotations/{annotation_id} | Delete Annotation
*AnnotationsApi* | [**get_annotation**](docs/AnnotationsApi.md#get_annotation) | **GET** /annotations/{annotation_id} | Get Annotation
*AnnotationsApi* | [**list_annotations**](docs/AnnotationsApi.md#list_annotations) | **GET** /annotations | List Annotations
*AnnotationsApi* | [**update_annotation**](docs/AnnotationsApi.md#update_annotation) | **PATCH** /annotations/{annotation_id} | Update Annotation
*AssistantSessionsApi* | [**chat**](docs/AssistantSessionsApi.md#chat) | **POST** /assistants/{assistant_session_id}/chat | Chat
*AssistantSessionsApi* | [**create_assistant**](docs/AssistantSessionsApi.md#create_assistant) | **POST** /assistants | Create Assistant
*AssistantSessionsApi* | [**get_assistant_session**](docs/AssistantSessionsApi.md#get_assistant_session) | **GET** /assistants/{assistant_session_id} | Get Assistant Session
*AssistantSessionsApi* | [**list_assistant_sessions**](docs/AssistantSessionsApi.md#list_assistant_sessions) | **GET** /assistants | List Assistant Sessions
*AudiencesApi* | [**create_audience**](docs/AudiencesApi.md#create_audience) | **POST** /audiences | Create Audience
*AudiencesApi* | [**delete_audience**](docs/AudiencesApi.md#delete_audience) | **DELETE** /audiences/{audience_id} | Delete Audience
*AudiencesApi* | [**edit_audience**](docs/AudiencesApi.md#edit_audience) | **PATCH** /audiences/{audience_id} | Edit Audience
*AudiencesApi* | [**extend_audience**](docs/AudiencesApi.md#extend_audience) | **POST** /audiences/{audience_id}/extend | Extend Audience
*AudiencesApi* | [**generate_audience**](docs/AudiencesApi.md#generate_audience) | **POST** /audiences/{audience_id}/generate | Generate Audience
*AudiencesApi* | [**get_audience**](docs/AudiencesApi.md#get_audience) | **GET** /audiences/{audience_id} | Get Audience
*AudiencesApi* | [**list_audiences**](docs/AudiencesApi.md#list_audiences) | **GET** /audiences | List Audiences
*ConversationFeedbackApi* | [**create**](docs/ConversationFeedbackApi.md#create) | **POST** /feedback | Create
*ConversationFeedbackApi* | [**delete_feedback**](docs/ConversationFeedbackApi.md#delete_feedback) | **DELETE** /feedback/{feedback_id} | Delete Feedback
*ConversationFeedbackApi* | [**get_feedback**](docs/ConversationFeedbackApi.md#get_feedback) | **GET** /feedback/{conversation_id} | Get Feedback
*ConversationFeedbackApi* | [**list_feedback**](docs/ConversationFeedbackApi.md#list_feedback) | **GET** /feedback | List Feedback
*ConversationFeedbackApi* | [**update_feedback**](docs/ConversationFeedbackApi.md#update_feedback) | **PUT** /feedback/{feedback_id} | Update Feedback
*ConversationsApi* | [**get_conversation**](docs/ConversationsApi.md#get_conversation) | **GET** /conversations/{conversation_id} | Get Conversation
*ConversationsApi* | [**list_conversations**](docs/ConversationsApi.md#list_conversations) | **GET** /conversations | List Conversations
*CopilotSessionsApi* | [**create_session**](docs/CopilotSessionsApi.md#create_session) | **POST** /copilots/{project_id}/sessions | Create Session
*CopilotSessionsApi* | [**delete_session**](docs/CopilotSessionsApi.md#delete_session) | **DELETE** /copilots/{project_id}/sessions/{session_id} | Delete Session
*CopilotSessionsApi* | [**get_session**](docs/CopilotSessionsApi.md#get_session) | **GET** /copilots/{project_id}/sessions/{session_id} | Get Session
*CopilotSessionsApi* | [**list_sessions**](docs/CopilotSessionsApi.md#list_sessions) | **GET** /copilots/{project_id}/sessions | List Sessions
*CopilotSessionsApi* | [**update_session**](docs/CopilotSessionsApi.md#update_session) | **PATCH** /copilots/{project_id}/sessions/{session_id} | Update Session
*FilesApi* | [**create_file**](docs/FilesApi.md#create_file) | **POST** /files | Create File
*FilesApi* | [**delete_file**](docs/FilesApi.md#delete_file) | **DELETE** /files/{file_id} | Delete File
*FilesApi* | [**get_file**](docs/FilesApi.md#get_file) | **GET** /files/{file_id} | Get File
*FilesApi* | [**get_file_download_url**](docs/FilesApi.md#get_file_download_url) | **POST** /files/{file_id}/download | Get File Download Url
*FilesApi* | [**list_files**](docs/FilesApi.md#list_files) | **GET** /files | List Files
*FilesApi* | [**start_processing**](docs/FilesApi.md#start_processing) | **POST** /files/{file_id}/process | Start Processing
*FilesApi* | [**upload_file_proxy**](docs/FilesApi.md#upload_file_proxy) | **POST** /files/{file_id}/upload | Upload File Proxy
*HealthApi* | [**health_check**](docs/HealthApi.md#health_check) | **GET** /health | Health Check
*InterviewsApi* | [**get_interview**](docs/InterviewsApi.md#get_interview) | **GET** /interviews/{interview_id} | Get Interview
*InterviewsApi* | [**interview_follow_up**](docs/InterviewsApi.md#interview_follow_up) | **POST** /interviews/{interview_id}/follow_up | Interview Follow Up
*InterviewsApi* | [**list_interviews**](docs/InterviewsApi.md#list_interviews) | **GET** /interviews | List Interviews
*InterviewsApi* | [**regenerate_interview**](docs/InterviewsApi.md#regenerate_interview) | **POST** /interviews/{interview_id}/regenerate | Regenerate Interview
*KnowledgeGraphsApi* | [**get_knowledge_graph**](docs/KnowledgeGraphsApi.md#get_knowledge_graph) | **GET** /knowledgeGraphs/{knowledge_graph_id} | Get Knowledge Graph
*KnowledgeGraphsApi* | [**list_knowledge_graphs**](docs/KnowledgeGraphsApi.md#list_knowledge_graphs) | **GET** /knowledgeGraphs | List Knowledge Graphs
*PlansApi* | [**create_plan**](docs/PlansApi.md#create_plan) | **POST** /plans | Create Plan
*PlansApi* | [**delete_plan**](docs/PlansApi.md#delete_plan) | **DELETE** /plans/{plan_id} | Delete Plan
*PlansApi* | [**get_plan**](docs/PlansApi.md#get_plan) | **GET** /plans/{plan_id} | Get Plan
*PlansApi* | [**list_plans**](docs/PlansApi.md#list_plans) | **GET** /plans | List Plans
*PlansApi* | [**update_plan**](docs/PlansApi.md#update_plan) | **PATCH** /plans/{plan_id} | Update Plan
*ProblemsApi* | [**create_problem**](docs/ProblemsApi.md#create_problem) | **POST** /problems | Create Problem
*ProblemsApi* | [**delete_problem**](docs/ProblemsApi.md#delete_problem) | **DELETE** /problems/{problem_id} | Delete Problem
*ProblemsApi* | [**edit_problem**](docs/ProblemsApi.md#edit_problem) | **PATCH** /problems/{problem_id} | Edit Problem
*ProblemsApi* | [**get_problem**](docs/ProblemsApi.md#get_problem) | **GET** /problems/{problem_id} | Get Problem
*ProblemsApi* | [**list_problems**](docs/ProblemsApi.md#list_problems) | **GET** /problems | List Problems
*ProjectsApi* | [**get_project**](docs/ProjectsApi.md#get_project) | **GET** /projects/{project_id} | Get Project
*ProjectsApi* | [**list_projects**](docs/ProjectsApi.md#list_projects) | **GET** /projects | List Projects
*ProjectsApi* | [**stream_events**](docs/ProjectsApi.md#stream_events) | **GET** /projects/{project_id}/stream | Stream Events
*ReportsApi* | [**create_report**](docs/ReportsApi.md#create_report) | **POST** /reports | Create Report
*ReportsApi* | [**delete_report**](docs/ReportsApi.md#delete_report) | **DELETE** /reports/{report_id} | Delete Report
*ReportsApi* | [**generate_full_report**](docs/ReportsApi.md#generate_full_report) | **POST** /reports/{report_id}/generate | Generate Full Report
*ReportsApi* | [**generate_toc_endpoint**](docs/ReportsApi.md#generate_toc_endpoint) | **POST** /reports/{report_id}/generate-toc | Generate Toc Endpoint
*ReportsApi* | [**get_report**](docs/ReportsApi.md#get_report) | **GET** /reports/{report_id} | Get Report
*ReportsApi* | [**get_report_pdf**](docs/ReportsApi.md#get_report_pdf) | **GET** /reports/{report_id}/pdf | Get Report Pdf
*ReportsApi* | [**list_reports**](docs/ReportsApi.md#list_reports) | **GET** /reports | List Reports
*ReportsApi* | [**update_report**](docs/ReportsApi.md#update_report) | **PATCH** /reports/{report_id} | Update Report
*ResearchGoalsApi* | [**create_research_goals**](docs/ResearchGoalsApi.md#create_research_goals) | **POST** /researchGoals | Create Research Goals
*ResearchGoalsApi* | [**delete_research_goal**](docs/ResearchGoalsApi.md#delete_research_goal) | **DELETE** /researchGoals/{research_goal_id} | Delete Research Goal
*ResearchGoalsApi* | [**edit_research_goals**](docs/ResearchGoalsApi.md#edit_research_goals) | **PATCH** /researchGoals/{research_goal_id} | Edit Research Goals
*ResearchGoalsApi* | [**get_research_goal**](docs/ResearchGoalsApi.md#get_research_goal) | **GET** /researchGoals/{research_goal_id} | Get Research Goal
*ResearchGoalsApi* | [**list_research_goals**](docs/ResearchGoalsApi.md#list_research_goals) | **GET** /researchGoals | List Research Goals
*ScriptGenerationApi* | [**generate_interview_script**](docs/ScriptGenerationApi.md#generate_interview_script) | **POST** /scriptGeneration/generate | Generate Interview Script Suggestion
*SolutionsApi* | [**create_solution**](docs/SolutionsApi.md#create_solution) | **POST** /solutions | Create Solution
*SolutionsApi* | [**delete_solution**](docs/SolutionsApi.md#delete_solution) | **DELETE** /solutions/{solution_id} | Delete Solution
*SolutionsApi* | [**edit_solution**](docs/SolutionsApi.md#edit_solution) | **PATCH** /solutions/{solution_id} | Edit Solution
*SolutionsApi* | [**get_solution**](docs/SolutionsApi.md#get_solution) | **GET** /solutions/{solution_id} | Get Solution
*SolutionsApi* | [**list_solutions**](docs/SolutionsApi.md#list_solutions) | **GET** /solutions | List Solutions
*StudiesApi* | [**create_study**](docs/StudiesApi.md#create_study) | **POST** /studies | Create Study
*StudiesApi* | [**delete_study**](docs/StudiesApi.md#delete_study) | **DELETE** /studies/{study_id} | Delete Study
*StudiesApi* | [**edit_study**](docs/StudiesApi.md#edit_study) | **PATCH** /studies/{study_id} | Edit Study
*StudiesApi* | [**generate_knowledge_graph**](docs/StudiesApi.md#generate_knowledge_graph) | **POST** /studies/{study_id}/knowledge_graph | Generate Knowledge Graph
*StudiesApi* | [**generate_summary**](docs/StudiesApi.md#generate_summary) | **POST** /studies/{study_id}/summary | Generate Summary
*StudiesApi* | [**get_study**](docs/StudiesApi.md#get_study) | **GET** /studies/{study_id} | Get Study
*StudiesApi* | [**get_study_pdf**](docs/StudiesApi.md#get_study_pdf) | **GET** /studies/{study_id}/pdf | Download Study as PDF
*StudiesApi* | [**interview**](docs/StudiesApi.md#interview) | **POST** /studies/{study_id}/interview | Interview
*StudiesApi* | [**list_studies**](docs/StudiesApi.md#list_studies) | **GET** /studies | List Studies
*StudiesApi* | [**regenerate_all_interviews**](docs/StudiesApi.md#regenerate_all_interviews) | **POST** /studies/{study_id}/regenerate | Regenerate All Interviews
*StudiesApi* | [**study_follow_up**](docs/StudiesApi.md#study_follow_up) | **POST** /studies/{study_id}/follow_up | Study Follow Up
*SubPlansApi* | [**create_subplan**](docs/SubPlansApi.md#create_subplan) | **POST** /subplans | Create Subplan
*SubPlansApi* | [**delete_subplan**](docs/SubPlansApi.md#delete_subplan) | **DELETE** /subplans/{subplan_id} | Delete Subplan
*SubPlansApi* | [**execute_subplan**](docs/SubPlansApi.md#execute_subplan) | **POST** /subplans/{subplan_id}/execute | Execute Subplan
*SubPlansApi* | [**extend_subplan**](docs/SubPlansApi.md#extend_subplan) | **POST** /subplans/{subplan_id}/extend | Extend Subplan
*SubPlansApi* | [**generate_subplan_report**](docs/SubPlansApi.md#generate_subplan_report) | **POST** /subplans/{subplan_id}/report | Generate Subplan Report
*SubPlansApi* | [**get_report_pdf**](docs/SubPlansApi.md#get_report_pdf) | **GET** /subplans/{subplan_id}/report/{report_id}/pdf | Get Report Pdf
*SubPlansApi* | [**get_subplan**](docs/SubPlansApi.md#get_subplan) | **GET** /subplans/{subplan_id} | Get Subplan
*SubPlansApi* | [**list_subplans**](docs/SubPlansApi.md#list_subplans) | **GET** /subplans | List Subplans
*SubPlansApi* | [**subplan_follow_up**](docs/SubPlansApi.md#subplan_follow_up) | **POST** /subplans/{subplan_id}/follow_up | Subplan Follow Up
*SubPlansApi* | [**update_subplan**](docs/SubPlansApi.md#update_subplan) | **PATCH** /subplans/{sub_plan_id} | Update Subplan
*SuggestionsApi* | [**create_suggestion**](docs/SuggestionsApi.md#create_suggestion) | **POST** /suggestions | Create Suggestion
*SuggestionsApi* | [**delete_suggestion**](docs/SuggestionsApi.md#delete_suggestion) | **DELETE** /suggestions/{suggestion_id} | Delete Suggestion
*SuggestionsApi* | [**execute_suggestion**](docs/SuggestionsApi.md#execute_suggestion) | **POST** /suggestions/{suggestion_id}/execute | Execute Suggestion
*SuggestionsApi* | [**get_suggestion**](docs/SuggestionsApi.md#get_suggestion) | **GET** /suggestions/{suggestion_id} | Get Suggestion
*SuggestionsApi* | [**list_suggestions**](docs/SuggestionsApi.md#list_suggestions) | **GET** /suggestions | List Suggestions
*SuggestionsApi* | [**regenerate_suggestion**](docs/SuggestionsApi.md#regenerate_suggestion) | **POST** /suggestions/{suggestion_id}/regenerate | Regenerate Suggestion
*SuggestionsApi* | [**update_suggestion**](docs/SuggestionsApi.md#update_suggestion) | **PATCH** /suggestions/{suggestion_id} | Update Suggestion
*SummariesApi* | [**export_summary**](docs/SummariesApi.md#export_summary) | **GET** /summaries/{summary_id}/export | Export Summary
*SummariesApi* | [**get_summary**](docs/SummariesApi.md#get_summary) | **GET** /summaries/{summary_id} | Get Summary
*SummariesApi* | [**list_summaries**](docs/SummariesApi.md#list_summaries) | **GET** /summaries | List Summaries
*SummariesApi* | [**summary_follow_up**](docs/SummariesApi.md#summary_follow_up) | **POST** /summaries/{summary_id}/follow_up | Summary Follow Up
*SyntheticUsersApi* | [**delete_synthetic_user**](docs/SyntheticUsersApi.md#delete_synthetic_user) | **DELETE** /syntheticUsers/{synthetic_user_id} | Delete Synthetic User
*SyntheticUsersApi* | [**edit_synthetic_user**](docs/SyntheticUsersApi.md#edit_synthetic_user) | **PATCH** /syntheticUsers/{synthetic_user_id} | Edit Synthetic User
*SyntheticUsersApi* | [**get_synthetic_user**](docs/SyntheticUsersApi.md#get_synthetic_user) | **GET** /syntheticUsers/{synthetic_user_id} | Get Synthetic User
*SyntheticUsersApi* | [**list_synthetic_users**](docs/SyntheticUsersApi.md#list_synthetic_users) | **GET** /syntheticUsers | List Synthetic Users
*SyntheticUsersApi* | [**regenerate_synthetic_user**](docs/SyntheticUsersApi.md#regenerate_synthetic_user) | **POST** /syntheticUsers/{synthetic_user_id}/regenerate | Regenerate Synthetic User
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /users/{user_id} | Get User
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /users | List Users
*WorkspacesApi* | [**get_workspace**](docs/WorkspacesApi.md#get_workspace) | **GET** /workspaces/{workspace_id} | Get Workspace
*WorkspacesApi* | [**list_workspaces**](docs/WorkspacesApi.md#list_workspaces) | **GET** /workspaces | List Workspaces


## Documentation For Models

 - [Annotation](docs/Annotation.md)
 - [AppApiSchemasPlannerSubPlanType](docs/AppApiSchemasPlannerSubPlanType.md)
 - [AppApiSchemasStudiesSubPlanType](docs/AppApiSchemasStudiesSubPlanType.md)
 - [AppUtilsAnnotationCreate1](docs/AppUtilsAnnotationCreate1.md)
 - [AppUtilsAnnotationCreate2](docs/AppUtilsAnnotationCreate2.md)
 - [AssistantChat](docs/AssistantChat.md)
 - [AssistantSession](docs/AssistantSession.md)
 - [AssistantSessionCreate](docs/AssistantSessionCreate.md)
 - [AssistantSessionMessage](docs/AssistantSessionMessage.md)
 - [Audience](docs/Audience.md)
 - [AudienceCreate](docs/AudienceCreate.md)
 - [AudienceExtend](docs/AudienceExtend.md)
 - [AudienceGenerate](docs/AudienceGenerate.md)
 - [AudienceUpdate](docs/AudienceUpdate.md)
 - [ConceptBase](docs/ConceptBase.md)
 - [ConceptInput](docs/ConceptInput.md)
 - [Conversation](docs/Conversation.md)
 - [ConversationCreate](docs/ConversationCreate.md)
 - [ConversationFeedback](docs/ConversationFeedback.md)
 - [ConversationFeedbackComment](docs/ConversationFeedbackComment.md)
 - [ConversationFeedbackCreate](docs/ConversationFeedbackCreate.md)
 - [ConversationFeedbackHelpful](docs/ConversationFeedbackHelpful.md)
 - [ConversationFeedbackType](docs/ConversationFeedbackType.md)
 - [ConversationFeedbackUpdate](docs/ConversationFeedbackUpdate.md)
 - [ConversationReference](docs/ConversationReference.md)
 - [Data](docs/Data.md)
 - [File](docs/File.md)
 - [FileCreate](docs/FileCreate.md)
 - [FileDownloadURL](docs/FileDownloadURL.md)
 - [FileWithPresignedURL](docs/FileWithPresignedURL.md)
 - [GenerateTOCRequest](docs/GenerateTOCRequest.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Interview](docs/Interview.md)
 - [KnowledgeGraph](docs/KnowledgeGraph.md)
 - [PageAnnotation](docs/PageAnnotation.md)
 - [PageAssistantSession](docs/PageAssistantSession.md)
 - [PageAudience](docs/PageAudience.md)
 - [PageConversation](docs/PageConversation.md)
 - [PageConversationFeedback](docs/PageConversationFeedback.md)
 - [PageFile](docs/PageFile.md)
 - [PageInterview](docs/PageInterview.md)
 - [PageKnowledgeGraph](docs/PageKnowledgeGraph.md)
 - [PagePlan](docs/PagePlan.md)
 - [PageProblem](docs/PageProblem.md)
 - [PageProject](docs/PageProject.md)
 - [PageResearchGoal](docs/PageResearchGoal.md)
 - [PageSolution](docs/PageSolution.md)
 - [PageStandaloneReport](docs/PageStandaloneReport.md)
 - [PageStudy](docs/PageStudy.md)
 - [PageSubPlan](docs/PageSubPlan.md)
 - [PageSuggestion](docs/PageSuggestion.md)
 - [PageSummary](docs/PageSummary.md)
 - [PageSyntheticUser](docs/PageSyntheticUser.md)
 - [PageUser](docs/PageUser.md)
 - [PageWorkspace](docs/PageWorkspace.md)
 - [Plan](docs/Plan.md)
 - [PlanCreate](docs/PlanCreate.md)
 - [PlanUpdate](docs/PlanUpdate.md)
 - [Problem](docs/Problem.md)
 - [ProblemCreate](docs/ProblemCreate.md)
 - [ProblemUpdate](docs/ProblemUpdate.md)
 - [Project](docs/Project.md)
 - [ProjectUserRole](docs/ProjectUserRole.md)
 - [Report](docs/Report.md)
 - [ReportTOCEntryInput](docs/ReportTOCEntryInput.md)
 - [ReportTOCEntryOutput](docs/ReportTOCEntryOutput.md)
 - [ResearchGoal](docs/ResearchGoal.md)
 - [ResearchGoalCreate](docs/ResearchGoalCreate.md)
 - [ResearchGoalUpdate](docs/ResearchGoalUpdate.md)
 - [ScriptGenerationOutput](docs/ScriptGenerationOutput.md)
 - [ScriptGenerationRequest](docs/ScriptGenerationRequest.md)
 - [SessionCreate](docs/SessionCreate.md)
 - [SessionResponse](docs/SessionResponse.md)
 - [SessionUpdate](docs/SessionUpdate.md)
 - [Solution](docs/Solution.md)
 - [SolutionCreate](docs/SolutionCreate.md)
 - [SolutionUpdate](docs/SolutionUpdate.md)
 - [StandaloneReport](docs/StandaloneReport.md)
 - [StandaloneReportCreate](docs/StandaloneReportCreate.md)
 - [StandaloneReportUpdate](docs/StandaloneReportUpdate.md)
 - [StatusResponse](docs/StatusResponse.md)
 - [Study](docs/Study.md)
 - [StudyCreate](docs/StudyCreate.md)
 - [StudyInterviews](docs/StudyInterviews.md)
 - [StudyProgress](docs/StudyProgress.md)
 - [StudyUpdate](docs/StudyUpdate.md)
 - [SubPlan](docs/SubPlan.md)
 - [SubPlanCreate](docs/SubPlanCreate.md)
 - [SubPlanExecutionOptions](docs/SubPlanExecutionOptions.md)
 - [SubPlanReport](docs/SubPlanReport.md)
 - [SubPlanUpdate](docs/SubPlanUpdate.md)
 - [Suggestion](docs/Suggestion.md)
 - [SuggestionCreate](docs/SuggestionCreate.md)
 - [SuggestionUpdate](docs/SuggestionUpdate.md)
 - [Summary](docs/Summary.md)
 - [SummaryCreate](docs/SummaryCreate.md)
 - [SummaryMessage](docs/SummaryMessage.md)
 - [SummaryMessageCreate](docs/SummaryMessageCreate.md)
 - [SummarySection](docs/SummarySection.md)
 - [SyntheticUser](docs/SyntheticUser.md)
 - [SyntheticUserPartial](docs/SyntheticUserPartial.md)
 - [User](docs/User.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [Workspace](docs/Workspace.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication


## Author




